@@ -13,11 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from oslo_log import log as logging
 import six
 from six.moves import http_client
 from six.moves.urllib import parse
 
-from stackalytics.openstack.common import log as logging
 from stackalytics.processor import utils
 
 
@@ -39,13 +39,17 @@ def link_to_launchpad_id(link):
 def lp_profile_by_launchpad_id(launchpad_id):
     LOG.debug('Lookup user id %s at Launchpad', launchpad_id)
     uri = LP_URI_V1 % ('~' + launchpad_id)
-    return utils.read_json_from_uri(uri)
+    lp_profile = utils.read_json_from_uri(uri)
+    utils.validate_lp_display_name(lp_profile)
+    return lp_profile
 
 
 def lp_profile_by_email(email):
     LOG.debug('Lookup user email %s at Launchpad', email)
     uri = LP_URI_V1 % ('people/?ws.op=getByEmail&email=' + email)
-    return utils.read_json_from_uri(uri)
+    lp_profile = utils.read_json_from_uri(uri)
+    utils.validate_lp_display_name(lp_profile)
+    return lp_profile
 
 
 def lp_module_exists(module):
@@ -94,4 +98,13 @@ def lp_bug_generator(module, modified_since):
         for record in chunk['entries']:
             yield record
 
+            related_tasks_uri = record['related_tasks_collection_link']
+            LOG.debug('Reading related task from uri %s', related_tasks_uri)
+            related_tasks = utils.read_json_from_uri(related_tasks_uri)
+            if not related_tasks:
+                LOG.warn('No data was read from uri %s', uri)
+            elif related_tasks['entries']:
+                for related_task in related_tasks['entries']:
+                    yield related_task
+
         uri = chunk.get('next_collection_link')
