@@ -13,20 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import collections
-import logging as std_logging
-
 from oslo_config import cfg
 from oslo_log import log as logging
 import psutil
-import six
 from six.moves.urllib import parse
-import yaml
 
 from stackalytics.processor import bps
 from stackalytics.processor import config
 from stackalytics.processor import default_data_processor
 from stackalytics.processor import driverlog
+from stackalytics.processor import governance
 from stackalytics.processor import lp
 from stackalytics.processor import mls
 from stackalytics.processor import mps
@@ -36,7 +32,6 @@ from stackalytics.processor import runtime_storage
 from stackalytics.processor import utils
 from stackalytics.processor import vcs
 
-
 LOG = logging.getLogger(__name__)
 
 
@@ -96,7 +91,7 @@ def _process_reviews(record_iterator, ci_map, module, branch):
 
 
 def _process_repo(repo, runtime_storage_inst, record_processor_inst,
-                  rcs_inst, bug_modified_since):
+                  rcs_inst):
     uri = repo['uri']
     LOG.info('Processing repo uri: %s', uri)
 
@@ -109,6 +104,10 @@ def _process_repo(repo, runtime_storage_inst, record_processor_inst,
                                      utils.merge_records)
 
     LOG.debug('Processing bugs for repo uri: %s', uri)
+    current_date = utils.date_to_timestamp('now')
+    bug_modified_since = runtime_storage_inst.get_by_key(
+        'bug_modified_since-%s' % repo['module'])
+
     bug_iterator = bps.log(repo, bug_modified_since)
     bug_iterator_typed = _record_typer(bug_iterator, 'bug')
     processed_bug_iterator = record_processor_inst.process(
@@ -116,6 +115,9 @@ def _process_repo(repo, runtime_storage_inst, record_processor_inst,
     runtime_storage_inst.set_records(processed_bug_iterator,
                                      utils.merge_records)
 
+    runtime_storage_inst.set_by_key(
+        'bug_modified_since-%s' % repo['module'], current_date)
+
     vcs_inst = vcs.get_vcs(repo, cfg.CONF.sources_root)
     vcs_inst.fetch()
 
@@ -201,21 +203,16 @@ def _post_process_records(record_processor_inst, repos):
 def process(runtime_storage_inst, record_processor_inst):
     repos = utils.load_repos(runtime_storage_inst)
 
-    current_date = utils.date_to_timestamp('now')
-    bug_modified_since = runtime_storage_inst.get_by_key('bug_modified_since')
-
     rcs_inst = rcs.get_rcs(cfg.CONF.review_uri)
     rcs_inst.setup(key_filename=cfg.CONF.ssh_key_filename,
                    username=cfg.CONF.ssh_username)
 
     for repo in repos:
         _process_repo(repo, runtime_storage_inst, record_processor_inst,
-                      rcs_inst, bug_modified_since)
+                      rcs_inst)
 
     rcs_inst.close()
 
-    runtime_storage_inst.set_by_key('bug_modified_since', current_date)
-
     LOG.info('Processing mail lists')
     mail_lists = runtime_storage_inst.get_by_key('mail_lists') or []
     for mail_list in mail_lists:
@@ -241,66 +238,10 @@ def apply_corrections(uri, runtime_storage_inst):
     runtime_storage_inst.apply_corrections(valid_corrections)
 
 
-def _read_official_projects_yaml(project_list_uri, release_names):
-    LOG.debug('Process list of projects from uri: %s', project_list_uri)
-    content = yaml.safe_load(utils.read_uri(project_list_uri))
-    module_groups = collections.defaultdict(
-        lambda: {'modules': [], 'releases': collections.defaultdict(list)})
-
-    official_integrated = module_groups['official-integrated']
-    official_integrated['tag'] = 'project_type'
-    official_integrated['module_group_name'] = 'official-integrated'
-    official_other = module_groups['official-other']
-    official_other['tag'] = 'project_type'
-    official_other['module_group_name'] = 'official-other'
-
-    for name, info in six.iteritems(content):
-        # take one official project
-
-        group_id = '%s-group' % name.lower()
-        module_groups[group_id]['module_group_name'] = '%s Official' % name
-        module_groups[group_id]['tag'] = 'program'
-
-        for module in info['projects']:
-            repo_split = module['repo'].split('/')
-            if len(repo_split) < 2:
-                continue  # valid repo must be in form of 'org/module'
-            module_name = repo_split[1]
-
-            module_groups[group_id]['modules'].append(module_name)
-
-            type_matched = False
-            if 'tags' in module:
-                for tag in module.get('tags'):
-                    tag_name = tag.get('name')
-
-                    if tag_name == 'integrated-release':
-                        type_matched = True  # project type is matched here
-                        project_type = 'official-other'
-                        for release_name in release_names:
-                            if release_name == tag.get('since'):
-                                project_type = 'official-integrated'
-
-                            module_groups[project_type]['releases'][
-                                release_name].append(module_name)
-
-            if not type_matched:
-                module_groups['official-other']['modules'].append(module_name)
-
-    # set ids for module groups
-    for group_id, group in six.iteritems(module_groups):
-        group['id'] = group_id
-
-    return module_groups
-
-
 def process_project_list(runtime_storage_inst, project_list_uri):
     module_groups = runtime_storage_inst.get_by_key('module_groups') or {}
-    release_names = [r['release_name'].lower()
-                     for r in runtime_storage_inst.get_by_key('releases')[1:]]
 
-    official_module_groups = _read_official_projects_yaml(
-        project_list_uri, release_names)
+    official_module_groups = governance.read_projects_yaml(project_list_uri)
     LOG.debug('Update module groups with official: %s', official_module_groups)
     module_groups.update(official_module_groups)
 
@@ -317,17 +258,8 @@ def process_project_list(runtime_storage_inst, project_list_uri):
 
 
 def main():
-    # init conf and logging
-    conf = cfg.CONF
-    conf.register_cli_opts(config.OPTS)
-    conf.register_opts(config.OPTS)
-    logging.register_options(conf)
-    logging.set_defaults()
-    conf(project='stackalytics')
-
-    logging.setup(conf, 'stackalytics')
-    LOG.info('Logging enabled')
-    conf.log_opt_values(LOG, std_logging.DEBUG)
+    utils.init_config_and_logging(config.CONNECTION_OPTS +
+                                  config.PROCESSOR_OPTS)
 
     runtime_storage_inst = runtime_storage.get_runtime_storage(
         cfg.CONF.runtime_storage_uri)
